aboutsummaryrefslogtreecommitdiff
path: root/git_hooks_deploy.go
diff options
context:
space:
mode:
Diffstat (limited to 'git_hooks_deploy.go')
-rw-r--r--git_hooks_deploy.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/git_hooks_deploy.go b/git_hooks_deploy.go
index 9965b43..d95d6a5 100644
--- a/git_hooks_deploy.go
+++ b/git_hooks_deploy.go
@@ -10,10 +10,10 @@ import (
"path/filepath"
)
// deploy_hooks_to_filesystem deploys the git hooks client to the filesystem.
// The git hooks client is expected to be embedded in resources_fs and must be
// pre-compiled during the build process; see the Makefile.
-func deploy_hooks_to_filesystem() (err error) {
+func deployHooks() (err error) {
err = func() (err error) {
var src_fd fs.File
var dst_fd *os.File
@@ -10,10 +10,10 @@ import (
"path/filepath"
)
-// deploy_hooks_to_filesystem deploys the git hooks client to the filesystem.
+// deployHooks deploys the git hooks client to the filesystem.
// The git hooks client is expected to be embedded in resources_fs and must be
// pre-compiled during the build process; see the Makefile.